package com.example.as_trak;

import androidx.annotation.RequiresApi;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.databinding.DataBindingUtil;

import android.annotation.SuppressLint;
import android.content.DialogInterface;
import android.content.res.Resources;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.PixelCopy;
import android.view.View;
import android.widget.Toast;

import com.example.as_trak.adapter.CargoListAdapter;
import com.example.as_trak.adapter.LoadInfoAdapter;
import com.example.as_trak.base.BaseActivity;
import com.example.as_trak.databinding.ActivityLoadScanBinding;
import com.example.as_trak.dialog.UpdataDialog;
import com.example.as_trak.entity.CargoInfo;
import com.example.as_trak.entity.FlightInfo;
import com.example.as_trak.entity.LoadOperation;
import com.example.as_trak.toast.LoadToast;

import org.litepal.LitePal;

import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

public class LoadScanActivity extends BaseActivity implements CargoListAdapter.CargoInfoCall, LoadInfoAdapter.LoadInfoCall, View.OnLongClickListener {
    private List<CargoInfo> cargoInfoList;
    private CargoListAdapter adapter;
    private List<LoadOperation> loadOperations;
    private CargoInfo cargoInfoTag;
    private FlightInfo flightInfo;
    private LoadToast loadToast;
    private LoadInfoAdapter loadInfoAdapter;
    // 定义时间格式
    private DateTimeFormatter formatter;
    private UpdataDialog updataDialog;
    // 装载完成对话框
    private AlertDialog.Builder alertDialog;
    private String[] loadStateList;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        com.example.as_trak.databinding.ActivityLoadScanBinding binding = DataBindingUtil.setContentView(this, R.layout.activity_load_scan);
        initScan();
        int id = getIntent().getIntExtra("id", 0);
        flightInfo = LitePal.where("id= ?", String.valueOf(id)).findFirst(FlightInfo.class);

        binding.setData(flightInfo);
        cargoInfoList = LitePal.where("flightId = ?", String.valueOf(id)).find(CargoInfo.class);
        adapter = new CargoListAdapter(this, this);
        adapter.setList(cargoInfoList);
        binding.setAdapter1(adapter);
        formatter = DateTimeFormatter.ofPattern("HH:mm");
        loadToast = new LoadToast(this);
        loadInfoAdapter = new LoadInfoAdapter(this, this);
        binding.setAdapter2(loadInfoAdapter);
        binding.loadScanSubmit.setOnLongClickListener(this);
        initDialog();
    }
    // 初始化弹窗
    @SuppressLint("NotifyDataSetChanged")
    private void initDialog() {
        loadStateList = getResources().getStringArray(R.array.loadState);
        updataDialog = new UpdataDialog(this);
        updataDialog.setUpdataDialogCall((code, index) -> {
            LoadOperation loadOperation = loadOperations.get(index);
            loadOperation.setOldLuggageCode(loadOperation.getLuggageCode());
            loadOperation.setLuggageCode(code);
            loadOperation.setState("修改");
            loadOperation.update(loadOperation.getId());
            loadInfoAdapter.notifyDataSetChanged();
        });
        alertDialog = new AlertDialog.Builder(this);
        alertDialog.setTitle("装载完成，选择装载量")
                // .setIcon(R.mipmap.ic_launcher)
                .setItems(loadStateList, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        Toast.makeText(LoadScanActivity.this,"装载完成" , Toast.LENGTH_SHORT).show();
                        cargoInfoTag.setState("装载完成");
                        cargoInfoTag.update(cargoInfoTag.getId());
                        cargoInfoTag.setLoadState(loadStateList[which]);
                        adapter.notifyDataSetChanged();
                        cargoInfoTag = null;

                    }
                }).setNegativeButton("取消", null).create();


    }

    // 扫码结果
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void sanCodeResult(String code) {
        super.sanCodeResult(code);
        if (cargoInfoTag == null) {
            Toast.makeText(this, "没有选择装载单元", Toast.LENGTH_SHORT).show();
            return;
        }
        int count = LitePal.where("flightId= ? and luggageCode=?  and (state IS NULL or state = '修改')  ", String.valueOf(flightInfo.getId()), code).count(LoadOperation.class);
        if (count > 0) {
            loadToast.show("行李条码重复");
            return;
        }
        LoadOperation loadOperation = new LoadOperation();
        loadOperation.setFlightCode(flightInfo.getFlightCode());
        loadOperation.setFlightId(flightInfo.getId());
        loadOperation.setDestination(flightInfo.getDestination());
        loadOperation.setTakeoffTime(flightInfo.getTakeoffTime());
        loadOperation.setCargoCode(cargoInfoTag.getCargoCode());
        loadOperation.setCargoId(cargoInfoTag.getId());
        loadOperation.setLuggageCode(code);
        // loadOperation.setUser();
        String formattedTime = LocalTime.now().format(formatter); // 格式化当前时间
        loadOperation.setLoadTime(formattedTime);
        loadOperation.setType("装载");
        loadOperation.save();
        loadOperations.add(loadOperation);
        loadInfoAdapter.notifyDataSetChanged();
        int size = loadOperations.size();
        Log.e("TAG", "更新的id:" + cargoInfoTag.getId() + "数量:" + size);
        cargoInfoTag.setCount(size);
        cargoInfoTag.setState("装载中");
        cargoInfoTag.update(cargoInfoTag.getId());

    }

    // 点击箱子
    @Override
    public void clickCargoInfo(int index) {
        cargoInfoTag = cargoInfoList.get(index);
        // Log.e("TAG", "clickCargoInfo:" + cargoInfoTag.toString());
        loadOperations = LitePal.where("cargoId =? and type = ? and (state IS NULL or state = '修改') ", String.valueOf(cargoInfoTag.getId()), "正常").find(LoadOperation.class);
        loadInfoAdapter.setList(loadOperations);
        loadInfoAdapter.notifyDataSetChanged();
    }

    // 修改行李号
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void updateCargoInfo(int index) {
        LoadOperation loadOperation = loadOperations.get(index);
        updataDialog.setIndex(index);
        updataDialog.setCode(loadOperation.getLuggageCode());
        updataDialog.show();
    }

    // 删除行李
    @SuppressLint("NotifyDataSetChanged")
    @Override
    public void deleteCargoInfo(int index) {
        LoadOperation loadOperation = loadOperations.get(index);
        loadOperation.setState("删除");
        loadOperation.update(loadOperation.getId());
        loadOperations.remove(index);
        cargoInfoTag.setCount(loadOperations.size());
        cargoInfoTag.update(cargoInfoTag.getId());
        loadInfoAdapter.notifyDataSetChanged();
    }


    public void loadOverupdate(View view) {
        CargoInfo cargoInfo = new CargoInfo();
        cargoInfo.setState("装载中");
        cargoInfo.updateAll();

    }


    // 装载完毕
    @Override
    @SuppressLint("NotifyDataSetChanged")
    public boolean onLongClick(View v) {
        if (cargoInfoTag == null) {
            return false;
        }
        alertDialog.show();
        return true;
    }
}